from typing import List

class point_3d:
    def __init__(self) -> None:
        pass
    
class element_module_properties:
    def __init__(self) -> None:
        pass
    
def get_all_identifiable_element_ids() -> List[int]:
    """get all identifiable element IDs (visible and unvisible)

    Returns:
        List[int]: element_id list
    """
    
def get_visible_identifiable_element_ids() -> List[int]:
    """get all visible identifiable elemnt ids

    Returns:
        List[int]: element_id list
    """
    
def get_invisible_identifiable_element_ids() -> List[int]:
    """Get invisible cadwork element IDs

    Returns:
        List[int]: element_id list
    """
    
def get_active_identifiable_element_ids() -> List[int]:
    """Get active cadwork element IDs

    Returns:
        List[int]: element_id list
    """

def get_inactive_all_identifiable_element_ids() -> List[int]:
    """Get inactive cadwork element IDs

    Returns:
        List[int]: element_id list
    """
    
def get_inactive_visible_identifiable_element_ids() -> List[int]:
    """Get inactive visible cadwork element IDs

    Returns:
        List[int]: element_id list
    """
    
def delete_elements(elements: List[int]) -> None:
    """Delete elements 

    Args:
        elements (List[int]): element IDs
    """
    
def join_elements(elements: List[int]) -> None:
    """join elements (group)

    Args:
        elements (List[int]): element IDs
    """
    
def join_top_level_elements(elements: List[int]) -> None:
    """join elements on highest leve. Previously joined elements are dissolved and joined at the top level.

    Args:
        elements (List[int]): element IDs
    """
    
def create_rectangular_beam_points(width: float, height: float, p1: point_3d, p2: point_3d, p3: point_3d) -> int:
    """create a rectangular beam. The direction (local x axis) and length of the beam is defined via p1 and p2. 
    The parameter p3 is used to set the local z vector (height) of the beams coordinate system. 

    Args:
        width (float): beam width
        height (float): beam height
        p1 (point_3d): start point
        p2 (point_3d): end point
        p3 (point_3d): height point

    Returns:
        int: element ID
    """
    
def create_circular_beam_points(diameter: float, p1: point_3d, p2: point_3d, p3: point_3d) -> int:
    """create a circular beam. The direction (local x axis) and length of the beam is defined via p1 and p2. 
   The parameter p3 is used to set the local z vector (height) of the beams coordinate system. 

    Args:
        diameter (float): circle diameter
        p1 (point_3d): start point
        p2 (point_3d): end point
        p3 (point_3d): height point

    Returns:
        int: element ID
    """
    
def create_square_beam_points(width: float, p1: point_3d, p2: point_3d, p3: point_3d) -> int:
    """create a square beam. The direction (local x axis) and length of the beam is defined via p1 and p2. 
    The parameter p3 is used to set the local z vector (height) of the beams coordinate system. 

    Args:
        width (float): beam width
        p1 (point_3d): start point
        p2 (point_3d): end point
        p3 (point_3d): height point

    Returns:
        int: element ID
    """
    
def create_rectangular_beam_vectors(length: float, width: float, height: float, p1: point_3d, xl: point_3d, zl: point_3d) -> int:
    """create a rectangular beam from vectors. The start point of the element is defined by p1. Then the direction (local x axis) is definied by p2 (e.g. point_3d(1.,0.,0.)).
    The local z vector is defined via p3 (e.g. point_3d(0.,1.,0.)). 

    Args:
        length (float): length of beam axis
        width (float): beam width
        height (float): beam height
        p1 (point_3d): start point 
        xl (point_3d): local x vector
        zl (point_3d): local z vector

    Returns:
        int: element ID
    """
    
def create_circular_beam_vectors(diameter: float, length: float, p1: point_3d, xl: point_3d, zl: point_3d) -> int:
    """create a circular beam from vectors. The start point of the element is defined by p1. Then the direction (local x axis) is definied by xl (e.g. point_3d(1.,0.,0.)).
    The local z vector is defined via zl (e.g. point_3d(0.,1.,0.)).

    Args:
        diameter (float): circle diameter
        length (float): beam/axis length
        p1 (point_3d): start point
        xl (point_3d): local x vector
        zl (point_3d): local z vector

    Returns:
        int: element ID
    """
    
def create_square_beam_vectors(width: float, length: float, p1: point_3d, xl: point_3d, zl: point_3d) -> int:
    """create a square beam from vectors. The start point of the element is defined by p1. Then the direction (local x axis) is definied by xl (e.g. point_3d(1.,0.,0.)).
    The local z vector is defined via zl (e.g. point_3d(0.,1.,0.)).

    Args:
        width (float): beam width
        length (float): beam/axis length
        p1 (point_3d): start point
        xl (point_3d): local x vector
        zl (point_3d): local z vector

    Returns:
        int: element ID
    """
    
def create_rectangular_panel_points(width: float, thickness: float, p1: point_3d, p2: point_3d, p3: point_3d) -> int:
    """create a rectangular panel. The direction (local x axis) and length of the panel is defined via p1 and p2. 
    The parameter (p3) is used to set the local z vector (thickness) of the beams coordinate system.

    Args:
        width (float): beam width
        thickness (float): beam thickness
        p1 (point_3d): start point
        p2 (point_3d): end point
        p3 (point_3d): height point

    Returns:
        int: element ID
    """
    
def create_rectangular_panel_vectors(width: float, thickness: float, length: float, p1: point_3d, xl: point_3d, zl: point_3d) -> int:
    """create a rectangular panel from vectors. The start point of the element is defined by p1. Then the direction (local x axis) is definied by p2 (e.g. point_3d(1.,0.,0.)).
    The local z vector is defined via p3 (e.g. point_3d(0.,1.,0.)). 

    Args:
        width (float): panel width
        thickness (float): panel thickness
        length (float):  panel/axis length
        p1 (point_3d): start point
        xl (point_3d): local x vector
        zl (point_3d): local z vector

    Returns:
        int: element ID
    """
    
def create_drilling_points(diameter: float, p1: point_3d, p2: point_3d) -> int:
    """Create a drilling from two points. 

    Args:
        diameter (float): drilling diameter
        p1 (point_3d): start point
        p2 (point_3d): end point

    Returns:
        int: element ID
    """
    
def create_drilling_vectors(diameter: float, length: float, p1: point_3d, xl:point_3d) -> int:
    """Create a drilling from a point and a direction vector. 

    Args:
        diameter (float): drilling diameter
        length (float): drilling length
        p1 (point_3d): start point
        xl (point_3d): vector direction

    Returns:
        int: [description]
    """
    
def create_line_points(p1: point_3d, p2: point_3d) -> int:
    """crete a line

    Args:
        p1 (point_3d): start point
        p2 (point_3d): end point

    Returns:
        int: element ID
    """
    
def create_line_vectors(length: float, p1: point_3d, xl: point_3d) -> int:
    """crete a line

    Args:
        length (float): line length
        p1 (point_3d): start point
        xl (point_3d): vector direction

    Returns:
        int: elmement id
    """
    
def create_node(p1: point_3d) -> int:
    """create a node

    Args:
        p1 (point_3d): point

    Returns:
        int: element ID
    """
    
def solder_elements(elements: List[int]) -> List[int]:
    """solder elements, if they are in contact. 

    Args:
        elements (List[int]): element IDs

    Returns:
        List[int]: element ID
    """
    
def convert_beam_to_panel(elements: List[int]) -> None:
    """convert beam(s) to panel(s)

    Args:
        elements (List[int]): element IDs
    """
    
def convert_panel_to_beam(elements: List[int]) -> None:
    """convert panel(s) to beam(s)

    Args:
        elements (List[int]): element IDs
    """
def delete_all_element_end_types(elements: List[int]) -> None:
    """delete end types

    Args:
        elements (List[int]): element IDs
    """
def delete_all_element_processes(elements: List[int]) -> None:
    """delete element processes

    Args:
        elements (List[int]): element IDs
    """
def move_element(elements: List[int], vector: point_3d) -> None:
    """move element by a vector

    Args:
        elements (List[int]): element IDs
        vector (point_3d): vector
    """
def create_polygon_beam(points: List[point_3d], thickness: float, xl: point_3d, zl: point_3d) -> int:
    """create a polygon beam. Define the polygon outline in a vertex list.  
    
    Args:
        points (List[point_3d]): vertex list
        thickness (float): beam thickness
        xl (point_3d): vector (length dir)
        zl (point_3d): vector (height dir)

    Returns:
        int: element ID
    """
def create_text_object(text: str, position: point_3d, xl: point_3d, zl: point_3d, size: float) -> int:
    """create text object

    Args:
        text (str): your text
        position (point_3d): location
        xl (point_3d): length dir
        zl (point_3d): height dir
        size (float): font size

    Returns:
        int: element ID
    """
def copy_elements(elements: List[int], vector: point_3d) -> List[int]:
    """copy elements

    Args:
        elements (List[int]): element IDs
        vector (point_3d): copy vector

    Returns:
        List[int]: element IDs
    """
def rotate_elements(elements: List[int], origin: point_3d, rotation_axis: point_3d, rotation_angle: float) -> None:
    """rotate elements

    Args:
        elements (List[int]): element IDs
        origin (point_3d): element origin (p1)
        rotation_axis (point_3d): vector axis
        rotation_angle (float): radians
    """
def subtract_elements(hard_elements: List[int], soft_elements: List[int]) -> List[int]:
    """Subtract elements. The first element is hard, the second soft.

    Args:
        hard_elements (List[int]): subtract with
        soft_elements (List[int]): subtract from

    Returns:
        List[int]: element IDs
    """
def check_element_id(element: int) -> bool:
    """check element ID

    Args:
        element (int): element ID

    Returns:
        bool: True/False
    """
def start_element_module_calculation(elements: List[int]) -> None:
    """start the elemend module calculation. Inputarguments are cover elements. 

    Args:
        elements (List[int]): element IDs (cover(s) architectural elementtypes)
    """
def set_element_detail_path(path: str) -> None:
    """set element detail path

    Args:
        path (str): path to elementmodule directory
    """
def get_element_detail_path() -> str:
    """get the path from active elmeentmodule

    Returns:
        str: path
    """
def get_element_cadwork_guid(element: int) -> str:
    """get cadwork element guid

    Args:
        element (int): element ID

    Returns:
        str: guid
    """
def get_element_from_cadwork_guid(guid: str) -> int:
    """get element from cadwork guid

    Args:
        guid (str): cadwork guid

    Returns:
        int: element ID
    """
def add_elements_to_undo(elements: List[int], number: int) -> None:
    """add elements to undo

    Args:
        elements (List[int]): element IDs
        number (int): enum(1:add, 2:modify)
    """
def make_undo() -> None:
    """make undo
    """
def make_redo() -> None:
    """make redo
    """
def split_elements(elements: List[int]) -> None:
    """split joined elmements

    Args:
        elements (List[int]): element IDs
    """
def set_line_to_marking_line(elements: List[int]) -> None:
    """modify a line to a marking line

    Args:
        elements (List[int]): element IDs
    """
def set_line_to_normal_line(elements: List[int]) -> None:
    """set line to normal line

    Args:
        elements (List[int]): element IDs
    """
def create_auto_export_solid_from_standard(elements: List[int], name:str, standard_element_name:str) -> int:
    """create automatic export solid from a standard export solid

    Args:
        elements (List[int]): element IDs
        name (str): new name for export solid
        standard_element_name (str): name of standard export solid

    Returns:
        int: element ID
    """
def set_element_module_properties_for_elements(elements: List[int], properties: element_module_properties) -> None:
    """set element module properties for elements

    Args:
        elements (List[int]): element IDs
        properties (element_module_properties): elment module properties
    """
def get_element_module_properties_for_element(element: int) -> element_module_properties:
    """get element module properties for element

    Args:
        element (int): element ID

    Returns:
        element_module_properties: elmement module properties
    """
def get_element_type_description(element: int) -> str:
    """get the description of the cadwork element type

    Args:
        element (int): element ID

    Returns:
        str: element type (e.g. beam)
    """
def create_text_object_with_font(text: str, position: point_3d, xl: point_3d, zl: point_3d, size: float, font: str) -> int:
    """create text object with font

    Args:
        text (str): your text
        position (point_3d): location
        xl (point_3d): length dir
        zl (point_3d): height dir
        size (float): font size
        font (str): font type (e.g. , "Times New Roman")

    Returns:
        int: element ID
    """
def get_opening_variant_ids(elements: List[int], opening_type: int) -> List[int]:
    """get opening variant ids

    Args:
        elements (List[int]): element IDs
        opening_type (int): number of opening type (enum)

    Returns:
        List[int]: element IDs
    """
def get_parent_container_id(element: int) -> int:
    """get parent container id

    Args:
        element (int): element ID

    Returns:
        int: element ID
    """
def get_export_solid_content_elements(element: int) -> List[int]:
    """get export solid content elements

    Args:
        element (int): element ID
    Returns:
        List[int]: element IDs
    """
def get_container_content_elements(element: int) -> List[int]:
    """get container content elements

    Args:
        element (int): element ID
    Returns:
        List[int]: element IDs
    """
def apply_transformation_coordinate(elments: List[int], old_point: point_3d, old_xl: point_3d, old_yl: point_3d, new_point: point_3d, new_xl: point_3d, new_yl: point_3d) -> None:
    """apply transformation coordinate to transform elements in 3D space

    Args:
        elments (List[int]): element IDs to transform
        old_point (point_3d): location origin
        old_xl (point_3d): origin x dir (vector)
        old_yl (point_3d): origin y dir (vector)
        new_point (point_3d): new location
        new_xl (point_3d): new x dir (vector)
        new_yl (point_3d): new y dir (vector)
    """
def delete_elements_with_undo(elements: List[int]) -> None:
    """delete elements and store the in undo

    Args:
        elements (List[int]): element IDs
    """
def add_created_elements_to_undo(elements: List[int]) -> None:
    """add created elementes to undo storeage

    Args:
        elements (List[int]): element IDs
    """
def add_modified_elements_to_undo(elements: List[int]) -> None:
    """add modified elementes to undo storeage

    Args:
        elements (List[int]): element IDs
    """
def recreate_elements(elements: List[int]) -> None:
    """recreate elements

    Args:
        elements (List[int]): element IDs
    """
def check_if_elements_are_in_collision(first_element:int, second_element:int) -> bool:
    """collision detection

    Args:
        element (int): first element ID
        element (int): second element ID

    Returns:
        bool: true/false
    """
def check_if_elements_are_in_contact(first_element:int, second_element:int) -> bool:
    """check if element faces are in contact

    Args:
        element (int): first element ID
        element (int): second element ID

    Returns:
        bool: true/false
    """
def create_multi_wall(elements: List[int]) -> None:
    """create multi wall

    Args:
        elements (List[int]): element IDs
    """
def get_user_element_ids() -> List[int]:
    """prompt that user select element IDs in 3D

    Returns:
        List[int]: elmement ids from selection
    """
def get_element_contact_vertices(first_element:int, second_element:int) -> List[point_3d]:
    """get element contact vertices

    Args:
        element (int): first element ID
        element (int): second element ID

    Returns:
        List[point_3d]: vertices list
    """
def get_nesting_parent_id(element:int) -> int:
    """get nesting parent id

    Args:
        element (int): element ID

    Returns:
        int: element ID
    """
def get_user_element_ids_with_existing(elements: List[int]) -> List[int]:
    """
    """
def clear_errors() -> None:
    """
    """
def glide_elements(elements: List[int], glide_point: point_3d) -> None:
    """glide elements

    Args:
        elements (List[int]): element IDs
        glide_point (point_3d): a glide point
    """
def get_element_contact_facets(first_element:int, second_element:int) -> List[List[point_3d]]:
    """get element contact faces

    Args:
        element (int): element ID
        element (int): element ID

    Returns:
        List[List[point_3d]]: contact face vertice list
    """
def get_element_raw_interface_vertices(first_element:int, second_element:int) -> List[point_3d]:
    """get element raw interface vertices

    Args:
        element (int): element ID
        element (int): element ID

    Returns:
        List[point_3d]: vertice list
    """
def cut_elements_with_miter(first_element:int, second_element:int) -> bool:
    """cut elements with miter. The miter is "cut" on loxal x-axis. 

    Args:
        element (int): element ID
        element (int): element ID

    Returns:
        bool: true/false
    """
def cut_element_with_plane(element: int, cut_plane_normal_vector: point_3d, distance_from_global_origin: float) -> bool:
    """cut an elment with a plane

    Args:
        element (int): element ID
        cut_plane_normal_vector (point_3d): plane normal vector
        distance_from_global_origin (float): distance from origin to plane

    Returns:
        bool: true/false
    """
def create_circular_mep(diameter: float, points: List[point_3d]) -> int:
    """create a circular mep

    Args:
        diameter (float): diameter
        points (List[point_3d]): vertice list

    Returns:
        int: element ID
    """
def create_rectangular_mep(width: float, depth: float, points: List[point_3d]) -> int:
    """create rectangular mep. The mep is orientied by an active element face.

    Args:
        width (float): mep width
        depth (float): mep depth
        points (List[point_3d]): vertice list

    Returns:
        int: element ID
    """
def slice_element_with_plane(element: int, cut_plane_normal_vector: point_3d, distance_from_global_origin: float) -> bool:
    """slice an elment with a plane

    Args:
        element (int): element ID
        cut_plane_normal_vector (point_3d): plane normal vector
        distance_from_global_origin (float): distance from origin to plane

    Returns:
        bool: true/false
    """
def create_auto_container_from_standard(elements: List[int], output_name: str, standard_element_name: str) -> int:
    """create an automatic container from a standard container

    Args:
        elements (List[int]): element ID
        output_name (str): container name
        standard_element_name (str): default container name

    Returns:
        int: element ID
    """
def create_auto_export_solid_from_standard_with_reference(elements: List[int], output_name: str, standard_element_name: str, reference_id: int) -> int:
    """create auto export solid from standard. The orientation is determined according to an element. 

    Args:
        elements (List[int]): element IDs
        output_name (str): export solid name
        standard_element_name (str): standard element name
        reference_id (int): element ID (reference - orientation)

    Returns:
        int: element ID
    """
def create_auto_container_from_standard_with_reference(elements: List[int], output_name: str, standard_element_name: str, reference_id: int) -> int:
    """create auto container from standard. The orientation is determined according to an element. 

    Args:
        elements (List[int]): element IDs
        output_name (str): export solid name
        standard_element_name (str): standard element name
        reference_id (int): element ID (reference - orientation)

    Returns:
        int: element ID
    """
def slice_elements_with_plane_and_get_new_elements(element: int, cut_plane_normal_vector: point_3d, distance_from_global_origin: point_3d) -> List[int]:
    """slice elments in two with a cutting plane.

    Args:
        element (int): element ID
        cut_plane_normal_vector (point_3d): plane normal vector
        distance_from_global_origin (float): distance from origin to plane

    Returns:
        bool: true/false
    """
def create_surface(points: List[point_3d]) -> int:
    """create a surface

    Args:
        points (List[point_3d]): vertex list

    Returns:
        int: element ID
    """
def convert_circular_beam_to_drilling(elements: List[int]) -> None:
    """convert circular beam to drilling 

    Args:
        elements (List[int]): element ID
    """
def get_standard_export_solid_list() -> List[str]:
    """get list of standard export solid names

    Returns:
        List[str]: names
    """
def get_standard_container_list() -> List[str]:
    """get list of standard container names

    Returns:
        List[str]: names
    """
def stretch_start_facet(elements: List[int], stretch_vector: point_3d) -> None:
    """stretch start facet of element(s)

    Args:
        elements (List[int]): element ID
        stretch_vector (point_3d): vector
    """
def stretch_end_facet(elements: List[int], stretch_vector: point_3d) -> None:
    """stretch end facet of element(s)

    Args:
        elements (List[int]): element ID
        stretch_vector (point_3d): vector
    """
def get_variant_sibling_element_ids(element: int) -> List[int]:
    """get variant sibling element IDs

    Args:
        element (int): element ID

    Returns:
        List[int]: element IDs
    """
def set_export_solid_contents(solid_id: int, elements: List[int]) -> None:
    """set export solid contents

    Args:
        solid_id (int): element ID
        elements (List[int]): element IDs
    """
def set_container_contents(container_id: int, elements: List[int]) -> None:
    """set container contents

    Args:
        solid_id (int): element ID
        elements (List[int]): element IDs
    """
def set_parent_opening_variants_opening_angle(elements: List[int], angle: float) -> None:
    """set parent opening variants opening angle

    Args:
        elements (List[int]): element IDs
        angle (float): radians
    """
def mirror_move_elements(elements: List[int], plane_definition: point_3d, plane_distance: float) -> None:
    """mirror elements (no copy)

    Args:
        elements (List[int]): element IDs
        plane_definition (point_3d): mirror plane
        plane_distance (float): perp. distance from origin to plane
    """
def mirror_copy_elements(elements: List[int], plane_definition: point_3d, plane_distance: float) -> List[int]:
    """mirror elements (copy)

    Args:
        elements (List[int]): element IDs
        plane_definition (point_3d): mirror plane
        plane_distance (float): perp. distance from origin to plane

    Returns:
        List[int]: element IDs
    """

def check_if_point_is_on_element(point:point_3d, element:int) -> bool:
    """Checks if a point is on a element

    Args:
        point (point_3d): a cadwork point
        element (int): element ID

    Returns:
        bool: if point 
    """

def check_if_point_is_in_element(point:point_3d, element:int) -> bool:
    """Check if point is in element

    Args:
        point (point_3d): a cadwork point
        element (int): element ID

    Returns:
        bool: if point 
    """
def create_bounding_box_local(element:int, elements:List[int]) -> int:
    """create a bounding box that is aligned to a reference element. 
    The bounding box includes all elements contained in the list.

    Args:
        element (int): element ID reference element
        elements (List[int]): element IDs

    Returns:
        int: element ID bounding box
    """
def create_bounding_box_global(elements: List[int]) -> int:
    """create a bounding box that is aligned to the global coordinate system.

    Args:
        elements (List[int]): element IDs

    Returns:
        int: element ID bounding box
    """
def extrude_surface_to_auxiliary_vector(element:int, vector:point_3d) -> int:
    """Extrude a surface to a auxiliary element. 

    Args:
        element (int): element ID
        vector (point_3d): vector e.g. point_3d(0,0,1200)

    Returns:
        int: element ID
    """
def extrude_surface_to_beam_vector(element:int, vector:point_3d) -> int:
    """Extrude a surface to a beam. 

    Args:
        element (int): element ID
        vector (point_3d): vector e.g. point_3d(0,0,1200)

    Returns:
        int: element ID
    """
def extrude_surface_to_panel_vector(element:int, vector:point_3d) -> int:
    """Extrude a surface to a panel.

    Args:
        element (int): element ID
        vector (point_3d): vector e.g. point_3d(0,0,1200)

    Returns:
        int: element ID
    """


from typing import List


def get_profile_length(profile: int) -> float: 
    """

    Args:
        profile (int): profile number

    Returns:
        float: length
    """
def get_edge_length(profile: int, edge: str) -> float: 
    """

    Args:
        profile (int): profile number
        edge (str): edge name

    Returns:
        float: length
    """
def get_all_caddy_element_ids() -> List[int]: 
    """

    Returns:
        List[int]: caddy elements
    """



from typing import List

class point_3d:
    def __init__(self)->None:
        pass

def export_2d_wireframe_with_clipboard(clipboard: int, with_layout: bool) -> None: 
    """

    Args:
        clipboard (int): clipboard element
        with_layout (bool): use layout
    """
def export_2d_hidden_lines_with_clipboard(clipboard: int, with_layout: bool) -> None: 
    """

    Args:
        clipboard (int): clipboard element
        with_layout (bool): use layout
    """
def export_2d_wireframe_with_2dc(file: str, with_layout: bool) -> None: 
    """

    Args:
        file (str): file path
        with_layout (bool): use layout
    """
def export_2d_hidden_lines_with_2dc(file: str, with_layout: bool) -> None: 
    """

    Args:
        file (str): file path
        with_layout (bool): use layout
    """
def export_wall_with_clipboard(clipboard: int, elements: List[int]) -> None: 
    """

    Args:
        clipboard (int): clipboard element
        elements (List[int]): element IDs
    """
def export_export_solid_with_clipboard(clipboard: int, elements: List[int]) -> None: 
    """

    Args:
        clipboard (int): clipboard element
        elements (List[int]): element IDs
    """
def export_piece_by_piece_with_clipboard(clipboard: int, elements: List[int]) -> None: 
    """

    Args:
        clipboard (int): clipboard element
        elements (List[int]): element IDs
    """
def assign_export_solid(elements: List[int], other_elements: List[int]) -> None: 
    """Assigns elements to an export solid

    Args:
        elements (List[int]): element IDs
        other_elements (List[int]): element IDs
    """
def export_container_with_clipboard(clipboard: int, elements: List[int]) -> None: 
    """

    Args:
        clipboard (int): clipboard element
        elements (List[int]): element IDs
    """
def add_wall_section_horizontal(element: int, position: point_3d) -> None: 
    """Adds a horizontal wall section

    Args:
        element (int): element ID
        position (point_3d): position vector
    """
def add_wall_section_vertical(element: int, position: point_3d) -> None: 
    """Adds a vertical wall section

    Args:
        element (int): element ID
        position (point_3d): position vector
    """
def export_wall_with_clipboard_and_presetting(clipboard: int, elements: List[int], file: str) -> None: 
    """

    Args:
        clipboard (int): clipboard element
        elements (List[int]): element IDs
        file (str): file path
    """
def load_export_piece_by_piece_settings(file: str) -> None: 
    """

    Args:
        file (str): file path
    """
def save_export_piece_by_piece_settings(file: str) -> None: 
    """

    Args:
        file (str): file path
    """




from typing import List


def export_production_list(elements: List[int], file: str) -> None: 
    """Exports a production list

    Args:
        elements (List[int]): element IDs
        file (str): file path
    """
def export_part_list(elements: List[int], file: str) -> None: 
    """Exports a part list

    Args:
        elements (List[int]): element IDs
        file (str): file path
    """
def check_position_numbers_production_list() -> List[int]: 
    """Checks the production list numbers and returns the element ids with discrepancies

    Returns:
        List[int]: element IDs
    """
def check_position_numbers_part_list() -> List[int]: 
    """Checks the part list numbers and returns the element ids with discrepancies

    Returns:
        List[int]: element IDs with discrepancies
    """
def export_production_list_with_settings(elements: List[int], file: str, settings: str) -> None: 
    """

    Args:
        elements (List[int]): element IDs
        file (str): file path
        settings (str): settings file path
    """
def export_part_list_with_settings(elements: List[int], file: str, settings: str) -> None: 
    """

    Args:
        elements (List[int]): element IDs
        file (str): file path
        settings (str): settings file path
    """
def generate_new_production_list_numbers(elements: List[int]) -> None: 
    """generates new positions numbers for production list

    Args:
        elements (List[int]): element IDs
    """
def generate_new_part_list_numbers(elements: List[int]) -> None: 
    """generates new positions numbers for part list

    Args:
        elements (List[int]): element IDs
    """
def load_production_list_calculation_settings(file: str) -> None: 
    """loads a settings file for production list calculation

    Args:
        file (str): file path
    """
def load_part_list_calculation_settings(file: str) -> None: 
    """_summary_

    Args:
        file (str): file path
    """

def generate_new_production_list_silently(elements: List[int], start_number: int, keep_existing_numbers: bool, with_containers: bool) -> None:
    """

    Args:
        elements (List[int]): element IDs
        start_number (int): a start number
        keep_existing_numbers (bool): keep existing numbers
        with_containers (bool): with containers

    """

def generate_new_part_list_silently(elements: List[int], start_number: int, keep_existing_numbers: bool, with_containers: bool) -> None:
    """_summary_

    Args:
        elements (List[int]): element IDs
        start_number (int): a start number
        keep_existing_numbers (bool): keep existing numbers
        with_containers (bool): with containers

    """



def export_btl(version: int, file: str) -> None: 
    """Exports a BTL file

    Args:
        version (int): BTL version
        file (str): file path
    """
def export_weinmann_mfb(version: int) -> None: 
    """ Exports a WUP file

    Args:
        version (int): WUP version
    """
def export_hundegger(version: int) -> None: 
    """Exports a Hundegger file

    Args:
        version (int): hundegger type
    """
def export_hundegger_with_file_path(version: int, file: str) -> None: 
    """Exports a Hundegger file

    Args:
        version (int): hundegger type
        file (str): file path
    """
def export_btl_with_presetting(version: int, file:str, presetting: str) -> None:
    """Exports a BTL file with a presetting file

    Args:
        version (int): BTL version
        file (str): file path
        presetting (str): export presetting file .xml
    """
def export_hundegger_with_file_path_and_presetting(type: int, file: str, presetting: str) -> None:
    """Exports a Hundegger file

    Args:
        type (int): hundegger type
        file (str): file path
        presetting (str): export presetting file .xml
    """
def load_hundegger_calculation_set(type: int, file:str) -> None:
    """

    Args:
        type (int): hundegger type
        file (str): file path
    """


from tkinter.messagebox import NO
from typing import List

class ifc_2x3_element_type():
    def __init__(self) -> None:
        pass


def get_ifc_guid(element: int) -> str: 
    """Get readable ifc guid. Convert readable guid to IfcGuid, see -> https://github.com/IfcOpenShell/IfcOpenShell/blob/master/src/ifcopenshell-python/ifcopenshell/guid.py

    Args:
        element (int): element ID

    Returns:
        str: readable guid
    """
def set_building_and_storey(elements: List[int], building: str, storey: str) -> None: 
    """Set bulding and storey 

    Args:
        elements (List[int]): element IDs
        building (str): building name
        storey (str): storey name
    """
def get_building(element: int) -> str: 
    """Get building name

    Args:
        element (int): element ID

    Returns:
        str: building name
    """
def get_storey(element: int) -> str: 
    """Get Storey

    Args:
        element (int): element ID

    Returns:
        str: storey name
    """

def get_ifc2x3_element_type(element: int) -> ifc_2x3_element_type: 
    """Get IFC element type. 

    Args:
        element (int): element ID

    Returns:
        ifc_2x3_element_type: ifc type 
    """
def set_ifc2x3_element_type(elements: List[int], ifc_2x3_element_type: ifc_2x3_element_type) -> None: 
    """Set IFC element type.

    Args:
        elements (List[int]): element IDs
        ifc_2x3_element_type (ifc_2x3_element_type): cadwork ifc element type
    """
def import_ifc_as_graphical_object(file: str) -> None: 
    """Import ifc as graphical object

    Args:
        file (str): path to ifc file
    """
def import_bcf(file: str) -> None: 
    """Import bcf file.

    Args:
        file (str): path to bcf file
    """
def export_bcf(file: str) -> None: 
    """Export bcf file. 

    Args:
        file (str): Destination path 
    """
def export_ifc(elements: List[int], file: str) -> None: 
    """Export an ifc file. 

    Args:
        elements (List[int]): element IDs
        file (str): Destination path 
    """

def convert_exchange_objects(elements: List[int]) -> List[int]:
    """Convert exchange objects to cadwork elements 

    Args:
        elements (List[int]): element IDs

    Returns:
        List[int]: converted elements 
    """

def get_all_buildings() -> List[str]:
    """Get all, in 3D, existing buildings 

    Returns:
        List[str]: building names 
    """

def get_all_storeys(building_name:str) -> List[str]:
    """Get all Storeys from a building.

    Args:
        building_name (str): building name

    Returns:
        List[str]: storey names 
    """


def get_storey_height(building_name:str, storey_name:str) -> float:
    """Get the storey height. 

    Args:
        building_name (str): building name
        storey_name (str): storey name

    Returns:
        float: storey elevation height
    """


def import_ifc_return_exchange_objects(file_path:str) -> None:
    """Import ifc as exchange objects

    Args:
        file_path (str): file path
    """

def set_storey_height(building_name:str, storey_name:str, height:float) -> None:
    """Set the storey elevation. 

    Args:
        building_name (str): building name
        storey_name (str): storey name
        height (float): storey elevation 
    """


from typing import List

class point_3d():
    def __init__(self) -> None:
        pass

def create_standard_connector(name: str, start: point_3d, end: point_3d) -> int: 
    """Creates a standard connector axis between two points.

    Args:
        name (str): Name of the standard axis
        start (point_3d): Point 1
        end (point_3d): Point 2

    Returns:
        int: element ID
    """
def get_item_guid_by_name(name: str, number: int) -> str: 
    """Get CA guid item by element name

    Args:
        name (str): CA name
        number (int): item type

    Returns:
        str: guid
    """
def get_bolt_length(number: int) -> float: 
    """Gets the Bolt Length

    Args:
        number (int): element ID

    Returns:
        float: bolt length
    """
def set_bolt_length(number: int, value: float) -> None: 
    """Sets the Bolt Length

    Args:
        number (int): element ID
        value (float): length
    """
def get_bolt_over_length(number: int) -> float: 
    """Gets the Bolt OverLength

    Args:
        number (int): element ID

    Returns:
        float: bolt length
    """
def set_bolt_over_length(number: int, value: float) -> None: 
    """Set bolt OverLength

    Args:
        number (int): element ID
        value (float): length
    """
def get_bolt_length_automatic(number: int) -> bool: 
    """Returns if Bolt Length Automatic is set

    Args:
        number (int): element ID

    Returns:
        bool: check if automatic is set
    """
def set_bolt_length_automatic(number: int, value: bool) -> None: 
    """Set bolt length automatic

    Args:
        number (int): element ID
        value (bool): length automatic
    """
def get_bolt_item_guid(number: int) -> str: 
    """Gets the Guid of the Bolt Item

    Args:
        number (int): _description_

    Returns:
        str: _description_
    """
def set_bolt_item(number: int, item: str) -> None: 
    """Sets the Bolt Item

    Args:
        number (int): element ID
        item (str): Item Guid
    """
def set_diameter(number: int, value: float) -> None: 
    """Sets the Drilling Diameter

    Args:
        number (int): element ID
        value (float): diameter
    """
def set_section_diameter(number: int, section_nr: int, value: float) -> None: 
    """Sets the Drilling Diameter for a specific Sections

    Args:
        number (int): element ID
        section_nr (int): Section number
        value (float): diameter
    """
def get_section_diameter(number: int, section_nr: int) -> float: 
    """Gets the Drilling Diameter of a specific Sections

    Args:
        number (int): element ID
        other_number (int): Section number

    Returns:
        float: diameter
    """
def get_axis_items_guids(number: int) -> List[str]: 
    """Returns a list of GUIDs of all axis items.

    Args:
        number (int): element ID

    Returns:
        List[str]: elemnt IDs
    """
def get_axis_item_name(guid: str) -> str: 
    """Returns the name of an axis item.

    Args:
        name (str): guid

    Returns:
        str: element name
    """
def get_axis_item_material(name: str) -> str: 
    """Returns the material of an axis item.

    Args:
        name (str): guid

    Returns:
        str: element name
    """
def get_axis_item_norm(name: str) -> str: 
    """Returns the norm of an axis item.

    Args:
        name (str): guid

    Returns:
        str: norm
    """
def get_axis_item_strength_category(name: str) -> str: 
    """Returns the strength category of an axis item.

    Args:
        name (str): guid

    Returns:
        str: strength category 
    """
def get_axis_item_user_field(name: str, number: int) -> str: 
    """Returns an userfield value of an axis item.

    Args:
        name (str): guid
        number (int): item number

    Returns:
        str: item user field
    """
def get_axis_item_order_number(name: str) -> str: 
    """Returns the strength category of an axis item.

    Args:
        name (str): guid

    Returns:
        str: item order number
    """
def get_bolt_order_number(number: int) -> str: 
    """Returns the ordernumber of a bolt item.

    Args:
        number (int): element ID

    Returns:
        str: Order number
    """
def check_axis(number: int) -> bool: 
    """Check connector axis. 

    Args:
        number (int): element ID

    Returns:
        bool: result
    """

def update_axis_cutting_ability(elements:List[int]) -> None:
    """Update Connector axis cutting ability.

    Args:
        elements (List[int]): element IDs
    """


from tkinter.messagebox import NO
from typing import List

class layer_settings():
    def __init__(self) -> None:
        pass

class extended_settings():
    def __init__(self) -> None:
        pass
    
class output_type():
    def __init__(self) -> None:
        pass
    
class process_type():
    def __init__(self) -> None:
        pass

class element_type():
    def __init__(self) -> None:
        pass

class element_module_properties():
    def __init__(self) -> None:
        pass

class point_3d:
    def __init__(self)->None:
        pass
    
def get_name(element: int) -> str:
    """get element name

    Args:
        element (int): elmement id

    Returns:
        str: element name
    """


def set_name(elements: List[int], name: str) -> None: 
    """

    Args:
        elements (List[int]): element IDs
        name (str): name
    """


def get_group(element: int) -> str: 
    """

    Args:
        element (int): element ID

    Returns:
        str: group name
    """


def set_group(elements: List[int], group: str) -> None: 
    """_summary_

    Args:
        elements (List[int]): element IDs
        group (str): group name
    """


def get_subgroup(element: int) -> str: 
    """_summary_

    Args:
        element (int): element ID

    Returns:
        str: subgroup name
    """


def set_subgroup(elements: List[int], subgroup: str) -> None: 
    """

    Args:
        elements (List[int]): element IDs
        subgroup (str): subgroup name
    """


def get_comment(element: int) -> str: 
    """

    Args:
        element (int): element ID

    Returns:
        str: comment
    """


def set_comment(elements: List[int], comment: str) -> None: 
    """_summary_

    Args:
        elements (List[int]): element IDs
        comment (str): comment
    """


def get_user_attribute(element: int, number: int) -> str: 
    """

    Args:
        element (int): element ID
        number (int): number user attribute

    Returns:
        str: user attribute name (key)
    """


def set_user_attribute(elements: List[int], number: int, value: str) -> None: 
    """

    Args:
        elements (List[int]): element IDs
        number (int): user attribute (key)
        value (str): user attribute name (value)
    """


def get_sku(element: int) -> str: 
    """

    Args:
        element (int): element ID

    Returns:
        str: sku code
    """


def set_sku(elements: List[int], sku: str) -> None: 
    """_summary_

    Args:
        elements (List[int]): element IDs
        sku (str): sku code
    """


def get_production_number(element: int) -> int: 
    """

    Args:
        element (int): element ID

    Returns:
        int: number
    """


def set_production_number(elements: List[int], number: int) -> None: 
    """

    Args:
        elements (List[int]): element IDs
        number (int): production number
    """


def get_part_number(element: int) -> int: 
    """

    Args:
        element (int): element ID

    Returns:
        int: part number
    """


def set_part_number(elements: List[int], number: int) -> None: 
    """

    Args:
        elements (List[int]): element IDs
        number (int): part number
    """


def get_additional_data(element: int, code: str) -> str: 
    """Gets the element additional data

    Args:
        element (int): element ID
        code (str): data id 

    Returns:
        str: additional data
    """


def set_additional_data(elements: List[int], code: str, data_text: str) -> None: 
    """

    Args:
        elements (List[int]): element IDs
        code (str): data id
        data_text (str): additional data text
    """


def delete_additional_data(elements: List[int], code: str) -> None: 
    """Deletes the element additional data

    Args:
        elements (List[int]): element IDs
        code (str): data ID
    """


def get_user_attribute_name(number: int) -> str: 
    """Gets the user attribute name

    Args:
        number (int): Number user attribute number

    Returns:
        str: user attribute name
    """


def set_user_attribute_name(number: int, name: str) -> None: 
    """Sets the user attribute name

    Args:
        number (int): Number user attribute number
        name (str): User attribute name user attribute name
    """


def get_wall_situation(element: int) -> str: 
    """Gets the element wall situation

    Args:
        element (int): element ID

    Returns:
        str: element wall situation
    """


def is_beam(element: int) -> bool: 
    """Tests if element is beam

    Args:
        element (int): element ID

    Returns:
        bool: is element beam
    """


def is_panel(element: int) -> bool: 
    """Tests if element is panel

    Args:
        element (int): element ID

    Returns:
        bool: is element panel
    """


def is_opening(element: int) -> bool: 
    """Tests if element is opening

    Args:
        element (int): element ID

    Returns:
        bool: is element opening
    """


def is_wall(element: int) -> bool: 
    """Tests if element is wall

    Args:
        element (int): element ID

    Returns:
        bool: is element wall
    """


def is_floor(element: int) -> bool: 
    """Tests if element is floor

    Args:
        element (int): element ID

    Returns:
        bool: is element floor
    """


def is_roof(element: int) -> bool: 
    """Tests if element is roof

    Args:
        element (int): element ID

    Returns:
        bool: is element roof
    """


def is_metal(element: int) -> bool: 
    """Tests if element is metal

    Args:
        element (int): element ID

    Returns:
        bool: is element metal
    """


def is_export_solid(element: int) -> bool: 
    """Tests if element is export solid

    Args:
        element (int): element ID

    Returns:
        bool: is element export solid
    """


def is_container(element: int) -> bool: 
    """Tests if element is container

    Args:
        element (int): element ID

    Returns:
        bool: is element container
    """


def is_connector_axis(element: int) -> bool: 
    """Tests if element is connector axis

    Args:
        element (int): element ID

    Returns:
        bool: is element connector axis
    """


def is_drilling(element: int) -> bool: 
    """Tests if element is drilling

    Args:
        element (int): element ID

    Returns:
        bool: is element drilling
    """


def is_node(element: int) -> bool: 
    """Tests if element is node

    Args:
        element (int): element ID

    Returns:
        bool: is element node
    """


def is_auxiliary(element: int) -> bool: 
    """Tests if element is auxiliary

    Args:
        element (int): element ID

    Returns:
        bool: is element auxiliary
    """

def is_line(element: int) -> bool: 
    """Tests if element is line

    Args:
        element (int): element ID

    Returns:
        bool: is element line
    """
    
def is_surface(element: int) -> bool: 
    """Tests if element is surface

    Args:
        element (int): element ID

    Returns:
        bool: is element surface
    """


def get_element_material_name(element: int) -> str: 
    """Gets the element material name

    Args:
        element (int): element ID

    Returns:
        bool: element material name
    """


def get_prefab_layer(element: int) -> str: 
    """Gets the element prefab layer

    Args:
        element (int): element ID

    Returns:
        bool: element prefab layer
    """


def get_machine_calculation_set(element: int) -> str: 
    """Gets the element machine calculation set

    Args:
        element (int): element ID

    Returns:
        str: element machine calculation set
    """


def get_cutting_set(element: int) -> str: 
    """Gets the element cutting set

    Args:
        element (int): element ID

    Returns:
        str: element cutting set
    """


def set_process_type_and_extended_settings_from_name(elements: List[int]) -> None: 
    """ Sets the element process type and extended settings from the element name

    Args:
        elements (List[int]): ElementIDs
    """


def set_name_process_type(name: str, process_type: process_type) -> None: 
    """Sets the process type for an element name

    Args:
        name (str): element name
        process_type (process_type): process type
    """


def get_name_process_type(name: int) -> process_type: 
    """Gets the process type for an element name

    Args:
        name (int): element name

    Returns:
        process_type: process type
    """


def set_name_extended_settings(name: str, extended_settings: extended_settings) -> None: 
    """Sets the extended settings for an element name

    Args:
        name (str): element name
        extended_settings (extended_settings): extended settings
    """


def get_name_extended_settings(name: str) -> extended_settings: 
    """Gets the extended settings for an element name

    Args:
        name (str): element name

    Returns:
        extended_settings: extended settings
    """


def get_output_type(element: int) -> output_type: 
    """Gets the element output type

    Args:
        element (int): element ID

    Returns:
        output_type: output type
    """


def set_output_type(elements: List[int], output_type: output_type) -> None: 
    """Sets the element output type

    Args:
        elements (List[int]):  element IDs
        output_type (output_type): element output type
    """


def get_extended_settings(element: int) -> extended_settings: 
    """Gets the element extended settings

    Args:
        element (int): element ID

    Returns:
        extended_settings: extended settings
    """


def set_extended_settings(elements: List[int], extended_settings: extended_settings) -> None: 
    """Sets the element extended settings

    Args:
        elements (List[int]): element IDs
        extended_settings (extended_settings): element extended settings
    """


def get_element_type(element: int) -> element_type: 
    """Gets the element type

    Args:
        element (int): element ID

    Returns:
        element_type: type
    """


def set_wall(elements: List[int]) -> None: 
    """Sets the element to wall

    Args:
        elements (List[int]): element IDs
    """
    
def set_log_wall(elements: List[int]) -> None: 
    """Sets the element to log wall

    Args:
        elements (List[int]): element IDs
    """


def set_floor(elements: List[int]) -> None: 
    """Sets the element to floor

    Args:
        elements (List[int]): element IDs
    """


def set_opening(elements: List[int]) -> None: 
    """Sets the element to opening

    Args:
        elements (List[int]): element IDs
    """


def get_fastening_attribute(element: int) -> str: 
    """Get the element fastening attribute

    Args:
        element (int): element ID

    Returns:
        str: element fastening attribute
    """


def set_fastening_attribute(elements: List[int], value: str) -> None: 
    """Sets the element fastening attribute

    Args:
        elements (List[int]): element IDs
        value (str): Value element fastening attribute
    """


def is_roof_surface(element: int) -> bool: 
    """Tests if the element is caddy object

    Args:
        element (int): element ID

    Returns:
        bool: is element caddy object
    """


def is_caddy_object(element: int) -> bool: 
    """Tests if the element is caddy object

    Args:
        element (int): element ID

    Returns:
        bool: is element caddy object
    """


def set_element_material(elements: List[int], material_id: int) -> None: 
    """Sets the element material

    Args:
        elements (List[int]): element IDs
        material_id (int): material ID
    """


def get_assembly_number(element: int) -> str: 
    """Get the elmement assembly number

    Args:
        element (int): element ID

    Returns:
        str: assembly number
    """


def set_assembly_number(elements: List[int], number: str) -> None: 
    """Set the elmement assembly number

    Args:
        elements (List[int]): element IDs
        number (str): assembly number
    """


def get_list_quantity(element: int) -> int: 
    """Get element quantity

    Args:
        element (int): elmement ID

    Returns:
        int: elmement quantity 
    """


def set_list_quantity(elements: List[int], quantity: int) -> None: 
    """Set element quantity

    Args:
        elements (List[int]): element IDs
        quantity (int): elmement quantity 
    """


def is_envelope(element: int) -> bool: 
    """Tests if the element is envelope

    Args:
        element (int): element ID

    Returns:
        bool: is element envelope
    """


def set_layer_settings(elements: List[int], layer_settings: layer_settings) -> None: 
    """Sets element layer settings

    Args:
        elements (List[int]): element IDs
        layer_settings (layer_settings): layer setting
    """


def set_ignore_in_vba_calculation(elements: List[int], value: bool) -> None: 
    """Sets if the element should be ignored in VBA Calculation

    Args:
        elements (List[int]): element IDs
        value (bool): Ignore
    """


def get_ignore_in_vba_calculation(element: int) -> bool: 
    """

    Args:
        element (int): element ID

    Returns:
        bool: Ignore
    """


def is_architecture_wall_2dc(element: int) -> bool: 
    """Tests if the element has a 2dc reference wall

    Args:
        element (int): element ID

    Returns:
        bool: is architecturewall 2dc
    """


def is_architecture_wall_xml(element: int) -> bool: 
    """Tests if the element has a xml reference wall

    Args:
        element (int): element ID

    Returns:
        bool: is architecturewall xml
    """


def set_reference_wall_2dc(elements: List[int], wall: str) -> None: 
    """Applies a new 2dc reference wall to an element

    Args:
        elements (List[int]): element IDs
        wall (str): 2dc file path
    """

def set_node_symbol(elements: List[int], node_symbol: int) -> None: 
    """Set a node symbol.
    ChessSquare, Circle, Cross, CrossSquare, FilledCircle, FilledSquare, HalfFilledSquare ,SmallSquare, Square

    Args:
        elements (List[int]): element IDs
        node_symbol (int): node symbol number
    """

def set_solid_floor(elements: List[int]) -> None:
    """set property for element type to solid floor 

    Args:
        elements (List[int]): element IDs
    """

def set_solid_roof(elements: List[int]) -> None:
    """set property for element type to solid roof 

    Args:
        elements (List[int]): element IDs
    """

def set_solid_wall(elements: List[int]) -> None:
    """set property for element type to solid wall 

    Args:
        elements (List[int]): element IDs
    """
    
def set_wall(elements: List[int]) -> None:
    """set element to type wall

    Args:
        elements (List[int]): element IDs
    """
    
def set_standard_part(elements: List[int]) -> None:
    """Sets covers (wall, opening or floor) to standard part

    Args:
        elements (List[int]): element IDs
    """

def update_auto_attribute() ->None:
    """Start update auto attribute
    """
    
def get_auto_attribute(element: int, number: int) -> str:
    """Get auto attribute

    Args:
        element (int): element ID
        number (int): auto attribute number

    Returns:
        str: name (value)
    """

def get_auto_attribute_name(element: int) -> str:
    """Get auto attribute name

    Args:
        element (int): element ID

    Returns:
        str: auto attribute name
    """
    
def get_steel_shape_name(element : int) -> str:
    """Get steel profile name

    Args:
        element (int): element ID

    Returns:
        str: steel profile name
    """

def get_standard_element_name(element : int) -> str:
    """Get standard element name

    Args:
        element (int): element ID

    Returns:
        str: standard element name
    """
    
def enable_attribute_display() -> None:
    """enable attribute display
    """

def disable_attribute_display() -> None:
    """disable attribute display
    """   
def get_prefab_layer_all_assigned(element : int) -> List[int]:
    """Get all layer to which the element is assigned

    Args:
        element (int): element ID

    Returns:
        List[int]: Layer
    """
def get_prefab_layer_with_dimensions(element : int) -> List[int]:
    """Check if element is exported with prefab layer with dimensions

    Args:
        element (int): element ID

    Returns:
        List[int]: layer number
    """
def get_prefab_layer_without_dimensions(element : int) -> List[int]:
    """Check if element is exported with prefab layer without dimensions

    Args:
        element (int): element ID

    Returns:
        List[int]: layer number
    """
def get_prefab_layer(element : int) -> str:
    """Get prefab layer. Returns layer values for "With dimensions", "Without dimensions", "Show Attributes".

    Args:
        element (int): element id

    Returns:
        str: value 
    """


from typing import List


def create_new_endtype(endtype_name: str, endtype_id: int, folder_name: str) -> int:
    """Create a new endtype

    Args:
        endtype_name (str): name
        endtype_id (int): endtype id
        folder_name (str): folder name

    Returns:
        int: [description]
    """
    
def get_endtype_id(name: str) -> int:
    """Gets the endtypeID by endtypename

    Args:
        name (str): endtype name

    Returns:
        int: endtype id
    """
def get_endtype_id_end(element_id: int) -> int:
    """Gets the endtypeID of the end face

    Args:
        arg0 (int): elmement ID

    Returns:
        int: endtype id
    """
def get_endtype_id_facet(element: int, face_number: int) -> int:
    """Gets the endtypeID of the face with a number

    Args:
        element (int): element ID
        face_number (int): face number 

    Returns:
        int: endtype id
    """
def get_endtype_id_start(element: int) -> int:
    """Gets the endtypeID of the start face

    Args:
        element (int): element ID

    Returns:
        int: endtype id
    """
def get_endtype_name(endtype_id: int) -> str:
    """Get endtype name

    Args:
        endtype_id (int): endtype ID

    Returns:
        str: endtype name
    """
def get_endtype_name_end(element: int) -> str:
    """Get endtype name end

    Args:
        endtype_id (int): endtype ID

    Returns:
        str: endtype name
    """
def get_endtype_name_facet(element: int, face_number: int) -> str:
    """Gets the endtypename of the face with a number

    Args:
        element (int): element ID
        face_number (int): face number

    Returns:
        str: endtype name facet
    """
def get_endtype_name_start(element: int) -> str:
    """Gets the endtypename of the start face

    Args:
        element (int): element ID

    Returns:
        str: endtype name start
    """

def set_endtype_id_end(element: int, endtype_id: int) -> None:
    """Sets the endtype to end face by endtypeID

    Args:
        element (int): element ID
        endtype_id (int): endtype ID
    """
def set_endtype_id_facet(element: int, endtype_id: int, face_number: int) -> None:
    """Sets the endtype to a face by endtypeID

    Args:
        element (int): element ID
        endtype_id (int): endtype ID
        face_number (int): face number
    """
    
def set_endtype_id_start(element: int, endtype_id: int) -> None:
    """Sets the endtype to start face by endtypeID

    Args:
        element (int): element ID
        endtype_id (int): endtype ID
    """
def set_endtype_name_end(arg0: int, arg1: str) -> None:
    """[summary]

    Args:
        arg0 (int): [description]
        arg1 (str): [description]
    """
def set_endtype_name_facet(element: int, name: str, face_number: int) -> None:
    """Sets the endtype to a face by endtypename

    Args:
        element (int): element ID
        name (str): name
        face_number (int): face number
    """
def set_endtype_name_start(element: int, face_number: str) -> None:
    """Sets the endtype to start face by endtypename

    Args:
        element (int): element ID
        face_number (str): face number
    """


from tokenize import Double
from typing import List

class point_3d:
    def __init__(self)->None:
        pass

def get_3d_version() -> int: 
    """

    Returns:
        int: version
    """
def get_3d_build() -> int: 
    """

    Returns:
        int: 3D build
    """
def get_3d_file_name() -> str: 
    """

    Returns:
        str: file name
    """
def get_3d_file_path() -> str: 
    """

    Returns:
        str: 3D file path
    """
def set_project_data(data_id: str, value: str) -> None: 
    """

    Args:
        data_id (str): project data ID
        value (str): project data
    """
def get_project_data(data_id: str) -> str: 
    """

    Args:
        data_id (str): project data ID

    Returns:
        str: project data
    """

def get_language() -> str: 
    """

    Returns:
        str: language
    """
def print_message(text: str) -> None: 
    """Prints a message

    Args:
        text (str): message/text
    """
def get_user_int(text: str) -> int: 
    """Prompts the user for an integer

    Args:
        text (str): message

    Returns:
        int: user integer
    """
def get_user_double(text: str) -> float: 
    """Prompts the user for a double

    Args:
        text (str): message

    Returns:
        float: user double
    """
def get_user_bool(text: str, default: bool=True) -> bool: 
    """Prompts the user for a boolean

    Args:
        text (str): message
        default (bool): Yes default value

    Returns:
        bool: user boolean
    """
def get_user_string(text: str) -> str: 
    """Prompts the user for a string

    Args:
        text (str): message

    Returns:
        str: user string
    """
def get_project_name() -> str: 
    """

    Returns:
        str: project name
    """
def set_project_name(value: str) -> None: 
    """

    Args:
        value (str): project name
    """
def get_project_number() -> str: 
    """

    Returns:
        str: project number
    """
def set_project_number(value: str) -> None: 
    """

    Args:
        value (str): project number
    """
def get_project_part() -> str: 
    """

    Returns:
        str: project part
    """
def set_project_part(value: str) -> None: 
    """

    Args:
        value (str): project part
    """
def get_project_architect() -> str: 
    """

    Returns:
        str: project architect
    """
def set_project_architect(value: str) -> None: 
    """

    Args:
        value (str): project architect
    """
def get_project_customer() -> str: 
    """_summary_

    Returns:
        str: value
    """
def set_project_customer(value: str) -> None: 
    """

    Args:
        value (str): value
    """
def get_project_designer() -> str: 
    """

    Returns:
        str: value
    """
def set_project_designer(value: str) -> None: 
    """

    Args:
        value (str): value
    """
def get_project_deadline() -> str: 
    """

    Returns:
        str: value
    """
def set_project_deadline(value: str) -> None: 
    """

    Args:
        value (str): value
    """
def get_project_user_attribute(number: int) -> str: 
    """

    Args:
        number (int): user attribute number

    Returns:
        str: value
    """
def set_project_user_attribute(number: int, value: str) -> None: 
    """

    Args:
        number (int): user attribute number
        value (str): value
    """
def get_project_user_attribute_name(number: int) -> str: 
    """

    Args:
        number (int): user attribute number

    Returns:
        str: value
    """
def set_project_user_attribute_name(number: int, value: str) -> None: 
    """

    Args:
        number (int): user attribute number
        value (str): value
    """
def get_project_latitude() -> float: 
    """

    Returns:
        float: latitude
    """
def get_project_longitude(value: float) -> None: 
    """

    Args:
        value (float): longitude
    """
def set_project_latitude() -> float: 
    """

    Returns:
        float: latitude value
    """
def set_project_longitude(value: float) -> None: 
    """

    Args:
        value (float): longitude value
    """
def get_project_address() -> str: 
    """

    Returns:
        str: value
    """
def set_project_address(value: float) -> None: 
    """

    Args:
        value (float): adress
    """
def get_project_postal_code() -> str: 
    """

    Returns:
        str: value
    """
def set_project_postal_code(value: float) -> None: 
    """

    Args:
        value (float): postal code
    """
def get_project_city() -> str: 
    """

    Returns:
        str: value
    """
def set_project_city(value: float) -> None: 
    """

    Args:
        value (float): value
    """
def get_project_country() -> str: 
    """

    Returns:
        str: value
    """
def set_project_country(value: float) -> None: 
    """

    Args:
        value (float): value
    """
def get_3d_userprofil_path() -> str: 
    """Get 3D userprofile path

    Returns:
        str: path
    """
def get_plugin_path() -> str:
    """Get 3D plugin path

    Returns:
        str: path
    """
def get_user_file_from_dialog(type_filter: str) -> str: 
    """ets a file with a dialog

    Args:
        type_filter (str): dialog file filter

    Returns:
        str: file path
    """
def get_client_number() -> str: 
    """

    Returns:
        str: client number
    """
def get_user_point() -> point_3d: 
    """Gets a point from the user

    Returns:
        point_3d: user point
    """
def disable_auto_display_refresh() -> None: 
    """Disables automatic display refresh
    """
def enable_auto_display_refresh() -> None: 
    """Enables automatic display refresh
    """
def create_new_guid() -> str: 
    """Creates a new GUID

    Returns:
        str: GUID
    """
def print_to_console(text: str) -> None: 
    """Prints a message to the console

    Args:
        text (str): message
    """
def export_screen_to_image(file: str, factor: int) -> None: 
    """Exports the screen to an image

    Args:
        file (str): file path
        factor (int): image factor
    """
def get_new_user_file_from_dialog(type_filter: str) -> str: 
    """Gets a new file with a dialog

    Args:
        type_filter (str): dialog file filter

    Returns:
        str: file path
    """
def api_autostart(name: str, option: int) -> None: 
    """

    Args:
        name (str): api name
        option (int): option
    """
def enable_autostart(name: str) -> None: 
    """

    Args:
        name (str): api name
    """
def disable_autostart(name: str) -> None: 
    """

    Args:
        name (str): api name
    """
def check_autostart(name: str) -> bool: 
    """

    Args:
        name (str): api name

    Returns:
        bool: result
    """
def delete_project_data(data_id: str) -> None: 
    """

    Args:
        data_id (str): data id
    """
def run_external_program(name: str) -> None: 
    """

    Args:
        name (str): external program name
    """
def save_3d_file_silently() -> None: 
    """Saves the 3D file silently
    """
def get_project_guid() -> str: 
    """

    Returns:
        str: GUID
    """
def get_licence_first_part() -> str: 
    """Gets the first part of the licence

    Returns:
        str: first part of license
    """
def get_licence_second_part() -> str: 
    """Gets the second part of the licence

    Returns:
        str: second part of licence
    """
def show_progress_bar() -> None: 
    """Shows a ProgressBar in the CommandBar
    """
def update_progress_bar(status: int) -> None: 
    """Updates the ProgressBar with a value

    Args:
        status (int): Value between 0 and 100
    """
def hide_progress_bar() -> None: 
    """Hides the ProgressBar
    """
def get_user_color(color: int) -> int: 
    """Gets a color choosen by the user

    Args:
        color (int): initial color

    Returns:
        int: color number
    """
def get_3d_linear_units() -> str: 
    """Gets the current linear units

    Returns:
        str: value
    """
def get_3d_linear_display_units() -> str: 
    """Gets the current display units

    Returns:
        str: value
    """
def get_3d_angular_units() -> str: 
    """_summary_

    Returns:
        str: value
    """
def get_3d_angular_display_units() -> str: 
    """Gets the current angular display units

    Returns:
        str: value
    """
def get_3d_build_date() -> str: 
    """Gets the current build date

    Returns:
        str: value
    """
def get_project_elevation() -> float: 
    """Gets the project elevation

    Returns:
        float: elevation
    """
def set_project_elevation(value: float) -> None: 
    """Sets the project elevation

    Args:
        value (float): value
    """
def push_check_and_query_data() -> None: 
    """disable check and query prompts
    utility_controller.push_check_and_query_data()
    utility_controller.change_check_and_query_data_to_no_queries()
    """
def pop_check_and_query_data() -> None: 
    """restores check and query prompts
    utility_controller.pop_check_and_query_data()
    """
def change_check_and_query_data_to_no_queries() -> None: 
    """
    """
def change_check_and_query_data_to_queries() -> None: 
    """
    """
def load_attribute_display_settings(file_path:str) -> None:
    """

    Args:
        file_path (str): a file path
    """
def load_element_attribute_display_settings(file_path:str, elements: List[int]) -> None:
    """

    Args:
        file_path (str): a file path
        elements (List[int]): element IDs
    """
def get_global_x_offset() -> float:
    """

    Returns:
        float: global x offset
    """
def set_global_x_offset(offset:float) -> None:
    """

    Args:
        offset (float): a offset value
    """
def get_global_y_offset() -> float:
    """

    Returns:
        float: global y offset
    """
def set_global_y_offset(offset:float) -> None:
    """

    Args:
        offset (float): a offset value
    """
def get_global_z_offset() -> float:
    """

    Returns:
        float: global z offset
    """
def set_global_z_offset(offset:float) -> None:
    """

    Args:
        offset (float): a offset value
    """
def show_north_arrow() -> None:
    """
    """
def hide_north_arrow() -> None:
    """
    """
def is_north_arrow_visible() -> bool:
    """checks if north arrow is visible

    Returns:
        bool: is visible
    """
def get_north_angle() -> float:
    """

    Returns:
        float: angle
    """
def set_north_angle(north_angle:float) -> None:
    """

    Args:
        north_angle (float): a angle value
    """
def get_millimetre_from_imperial_string(value:str) -> float:
    """

    Args:
        value (str): imperial string

    Returns:
        float: millimetre value
    """
def get_imperial_string_from_millimetre(value:float) -> str:
    """

    Args:
        value (float): millimetre value

    Returns:
        str: imperial string
    """



from typing import List


def add_scene(name: str) -> bool: 
    """

    Args:
        name (str): scene name

    Returns:
        bool: result
    """
def rename_scene(old_name: str, new_name: str) -> bool: 
    """

    Args:
        old_name (str): old scene name
        new_name (str): new scene name

    Returns:
        bool: result
    """
def delete_scene(name: str) -> bool: 
    """

    Args:
        name (str): name

    Returns:
        bool: result
    """
def add_elements_to_scene(name: str, elements: List[int]) -> bool: 
    """

    Args:
        name (str): name
        elements (List[int]): element IDs

    Returns:
        bool: result
    """
def remove_elements_from_scene(name: str, elements: List[int]) -> bool: 
    """

    Args:
        name (str): name
        elements (List[int]): element IDs

    Returns:
        bool: result
    """
def get_elements_from_scene(name: str) -> List[int]: 
    """

    Args:
        name (str): name

    Returns:
        List[int]: element IDs
    """
def activate_scene(name: str) -> bool: 
    """

    Args:
        name (str): name

    Returns:
        bool: result
    """




from typing import List


def display_simple_menu(items: List[str]) -> str: 
    """display a simple menu

    Args:
        items (List[str]): menu items

    Returns:
        str: item name
    """



from typing import List

class rgb_color():
    def __init__(self) -> None:
        pass

class visibility_state():
    def __init__(self) -> None:
        pass
    
class activation_state():
    def __init__(self) -> None:
        pass

def get_color(element: int) -> int: 
    """

    Args:
        number (int): element ID

    Returns:
        int: color number
    """
def set_color(element: int, color: int) -> None: 
    """

    Args:
        element (int): element ID
        color (int): color number
    """
def get_opengl_color(element: int) -> rgb_color: 
    """

    Args:
        element (int): element ID

    Returns:
        rgb_color: rgb color 
    """
def set_opengl_color(element: int, color: rgb_color) -> None: 
    """_summary_

    Args:
        element (int): element ID
        color (rgb_color): rgb color
    """
def is_active(element: int) -> bool: 
    """Tests if element is active

    Args:
        element (int): element ID

    Returns:
        bool: result
    """
def set_active(elements: List[int]) -> None: 
    """Set elements active

    Args:
        elements (List[int]): element IDs
    """
def set_inactive(elements: List[int]) -> None: 
    """Set elements inactive

    Args:
        elements (List[int]): element IDs
    """
def is_visible(element: int) -> bool: 
    """Check if element is visible

    Args:
        element (int): element ID

    Returns:
        bool: result
    """
def set_visible(elements: List[int]) -> None: 
    """Sets the element visible

    Args:
        elements (List[int]): element IDs
    """
def set_invisible(elements: List[int]) -> None: 
    """Sets the element invisible

    Args:
        elements (List[int]): element IDs
    """
def is_immutable(element: int) -> bool: 
    """ests if the element is immutable

    Args:
        element (int): element ID

    Returns:
        bool: result
    """
def set_immutable(elements: List[int]) -> None: 
    """Sets the element immutable

    Args:
        elements (List[int]): element IDs
    """
def set_mutable(elements: List[int]) -> None: 
    """Sets the element mutable

    Args:
        elements (List[int]): element IDs
    """
def show_all_elements() -> None: 
    """Shows all elements
    """
def hide_all_elements() -> None: 
    """Hide all elements
    """
def zoom_all_elements() -> None: 
    """zoom all elements
    """
def zoom_active_elements() -> None: 
    """zoom only active elements
    """
def refresh() -> None: 
    """Refresh the drawing area
    """
def set_material(elements: List[int], element: int) -> None: 
    """Sets the element material

    Args:
        elements (List[int]): element IDs
        element (int): element ID
    """
def get_material(element: int) -> int: 
    """Gets the element material

    Args:
        element (int): element ID

    Returns:
        int: material ID
    """
def save_visibility_state() -> visibility_state: 
    """Saves the visibility state

    Returns:
        visibility_state: visibility state
    """
def restore_visibility_state(state: visibility_state) -> None: 
    """Restores the visibility state

    Args:
        state (visibility_state): visibility state
    """
def save_activation_state() -> activation_state: 
    """_summary_

    Returns:
        activation_state: _description_
    """
def restore_activation_state(state: activation_state) -> None: 
    """Saves the activation state

    Args:
        state (activation_state): activation state
    """
def show_view_positive_x() -> None: 
    """
    """
def show_view_negative_x() -> None: 
    """
    """
def show_view_positive_y() -> None: 
    """
    """
def show_view_negative_y() -> None: 
    """
    """
def show_view_positive_z() -> None: 
    """
    """
def show_view_negative_z() -> None: 
    """
    """
def show_view_standard_axo() -> None: 
    """
    """
def show_view_wireframe() -> None: 
    """
    """
def show_view_hidden_lines() -> None: 
    """
    """
def show_view_dashed_hidden_lines() -> None: 
    """
    """
def show_view_shaded2() -> None: 
    """
    """
def show_view_shaded1() -> None: 
    """
    """
def is_selectable(element: int) -> bool: 
    """Returns if the element is selectable

    Args:
        element (int): element ID

    Returns:
        bool: result
    """
def set_unselectable(elements: List[int]) -> None: 
    """Sets a list of elements unselectable

    Args:
        elements (List[int]): element IDs
    """
def set_selectable(elements: List[int]) -> None: 
    """Sets a list of elements selectable

    Args:
        elements (List[int]): element IDs
    """




from typing import List


def create_material(name: str) -> int: 
    """

    Args:
        name (str): material name

    Returns:
        int: material ID
    """
def get_name(number: int) -> str: 
    """Get material name

    Args:
        number (int): element ID

    Returns:
        str: material name
    """
def set_name(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): a material name
    """
def get_group(number: int) -> str: 
    """get material group

    Args:
        number (int): element ID

    Returns:
        str: material group
    """
def set_group(number: int, value: str) -> None: 
    """set material group

    Args:
        number (int): element ID
        value (str): material group (name)
    """
def get_code(number: int) -> str: 
    """get material code

    Args:
        number (int): element ID

    Returns:
        str: material code
    """
def set_code(number: int, value: str) -> None: 
    """set material code

    Args:
        number (int): element ID
        value (str): material code
    """
def get_modulus_elasticity_1(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_modulus_elasticity_1(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_modulus_elasticity_2(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_modulus_elasticity_2(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_modulus_elasticity_3(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_modulus_elasticity_3(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_shear_modulus_1(number: int) -> float: 
    """_summary_

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_shear_modulus_1(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_shear_modulus_2(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_shear_modulus_2(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_price(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_price(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_price_type(number: int) -> str: 
    """

    Args:
        number (int): element ID

    Returns:
        str: _description_
    """
def set_price_type(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): _description_
    """
def get_thermal_conductivity(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_thermal_conductivity(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_heat_capacity(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_heat_capacity(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_u_min(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_u_min(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_u_max(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_u_max(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_fire_resistance_class(number: int) -> str: 
    """

    Args:
        number (int): element ID

    Returns:
        str: _description_
    """
def set_fire_resistance_class(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): _description_
    """
def get_smoke_class(number: int) -> str: 
    """

    Args:
        number (int): element ID

    Returns:
        str: _description_
    """
def set_smoke_class(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): _description_
    """
def get_drop_forming_class(number: int) -> str: 
    """

    Args:
        number (int): element ID

    Returns:
        str: _description_
    """
def set_drop_forming_class(number: int, value: str) -> None: 
    """

    Args:
        number (int): element ID
        value (str): _description_
    """
def get_burn_off_rate(number: int) -> float: 
    """

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_burn_off_rate(number: int, value: float) -> None: 
    """

    Args:
        number (int): element ID
        value (float): value
    """
def get_weight(number: int) -> float: 
    """get material weight

    Args:
        number (int): element ID

    Returns:
        float: value
    """
def set_weight(number: int, value: float) -> None: 
    """set material weight

    Args:
        number (int): element ID
        value (float): value
    """
def get_weight_type(number: int) -> str: 
    """gets the material weight type

    Args:
        number (int): element ID

    Returns:
        str: weight type
    """
def set_weight_type(number: int, value: str) -> None: 
    """sets the material weight type

    Args:
        number (int): element ID
        value (str): weight type
    """
def get_material_id(name: str) -> None: 
    """

    Args:
        name (str): material name
    """
def get_all_materials() -> List[int]: 
    """

    Returns:
        List[int]: all materials
    """



from typing import List

class point_3d:
    def __init__(self)->None:
        pass

def export_stl_file(elements: List[int], file: str) -> None:
    """ Exports an STL file

    Args:
        elements (List[int]): element IDs
        file (str): file path
    """
def import_step_file(file: str, scale: float) -> List[int]: 
    """Imports a STEP file

    Args:
        file (str): file path
        scale (float): file scale factor

    Returns:
        List[int]: element IDs
    """
def import_step_file_with_message_option(file: str, scale: float, option: bool) -> List[int]: 
    """Imports a STEP file

    Args:
        file (str): file path
        scale (float): file scale factor
        option (bool): hide message

    Returns:
        List[int]: element IDs
    """
def export_webgl(elements: List[int], file: str) -> None: 
    """_summary_

    Args:
        elements (List[int]): _description_
        file (str): _description_
    """
def export_3d_file(elements: List[int], file: str) -> None: 
    """Exports a WebGL file

    Args:
        elements (List[int]): element IDs
        file (str): file path
    """
def import_sat_file(file: str, scale: float, option: bool) -> List[int]: 
    """Imports an SAT file

    Args:
        file (str): file path
        scale (float): file scale factor
        option (bool): use binary mode

    Returns:
        List[int]: element IDs
    """
def import_3dc_file(file: str) -> List[int]: 
    """Imports a 3DC file

    Args:
        file (str): file path

    Returns:
        List[int]: element IDs
    """
def import_rhino_file(file: str, option: bool) -> List[int]: 
    """Imports a Rhino file

    Args:
        file (str): file path
        option (bool): import without dialog

    Returns:
        List[int]: element IDs
    """
def export_step_file(elements: List[int], file: str, scale: float, number: int, option: bool) -> None: 
    """Exports a STEP file

    Args:
        elements (List[int]): element IDs
        file (str): file path
        scale (float): file scale factor
        number (int): file version
        option (bool): use text mode
    """
def import_3dz_file(file: str) -> None: 
    """Imports a 3DZ file

    Args:
        file (str): file path
    """
def export_obj_file(elements: List[int], file: str) -> None: 
    """Exports a OBJ file

    Args:
        elements (List[int]): element IDs
        file (str): file path
    """
def import_sat_file_silently(file: str, scale: float, option: bool) -> List[int]: 
    """_summary_

    Args:
        file (str): _description_
        scale (float): _description_
        option (bool): _description_

    Returns:
        List[int]: _description_
    """
def export_fbx_file(elements: List[int], file: str, number: int) -> None: 
    """Export fbx file

    Args:
        elements (List[int]): element IDs
        file (str): file path
        number (int): fbx format  1 = "FBX binary(*.fbx) ; 2 = "FBX ascii(*.fbx)" ; 3 = "FBX encrypted(*.fbx)" ; 4 = "FBX 6.0 binary(*.fbx)" ; 5 = "FBX 6.0 ascii(*.fbx)" ; 6 = "FBX 6.0 encrypted(*.fbx)"
    """
def import_3dc_file_with_glide(file: str) -> List[int]: 
    """Imports a 3DC file with glide

    Args:
        file (str): file path

    Returns:
        List[int]: element IDs
    """
def import_btl_file(file: str) -> None: 
    """Imports a BTL file

    Args:
        file (str): file path
    """
def export_3dc_file(elements: List[int], file: str) -> None: 
    """Exports a 3D/3DC file

    Args:
        elements (List[int]): element IDs
        file (str): file path
    """
def import_btl_file_for_nesting(file: str) -> None: 
    """Imports a BTL file for nesting

    Args:
        file (str): file path
    """
def export_btl_file_for_nesting(file: str) -> None: 
    """Exports a BTL file for nesting

    Args:
        file (str): file path
    """
def export_rhino_file(elements: List[int], file: str, version: int, user_efault_assignment: bool, write_standard_attributes: bool) -> None: 
    """Exports a 3dm rhino file

    Args:
        elements (List[int]): element IDs
        file (str): file path
        version (int): Rhino version V5.0 = 5, V6.0 = 6, V7.0 = 7
        user_efault_assignment (bool): true: default assignment is used; false: no attributes are exported
        write_standard_attributes (bool): see checkbox in assignment dialog
    """
def export_sat_file(elements: List[int], file: str, scale: float, option: bool, number: int) -> None: 
    """exports a SAT File

    Args:
        elements (List[int]): element IDs
        file (str): file path
        scale (float): scale factor
        option (bool): binary 
        number (int): version
    """

def import_variant_file(file:str, insert_point:point_3d)-> List[int]:
    """imports a variant by .val-File

    Args:
        file (str): file path
        insert_point (point_3d): insert point

    Returns:
        List[int]: element IDs
    """

def set_blum_export_path(file:str) -> None:
    """Set blum export path

    Args:
        file (str): file path
    """

def get_blum_export_path() -> str:
    """Get blum export path

    Returns:
        str: file path
    """




from typing import List


class layer_settings():
    def __init__(self) -> None:
        pass

class extended_settings():
    def __init__(self) -> None:
        pass
    
class output_type():
    def __init__(self) -> None:
        pass
    
class process_type():
    def __init__(self) -> None:
        pass
    def is_hip_valley(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_jack_rafter(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_log(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_none(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_panel_1(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_panel_2(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_panel_3(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_panel_4(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_panel_5(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_purlin(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_rafter(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_rough_volume_framed_wall(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_rough_volume_log_home(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_rough_volume_solid_wood_wall(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_stud(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_tread(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_truss(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_user_1(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_user_2(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_user_3(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_user_4(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def is_user_5(self, output_type:output_type)->bool:
        """

        Args:
            output_type (output_type): output type

        Returns:
            bool: condition
        """
    def set_hip_valley(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_jack_rafter(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_log(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_none(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_panel_1(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_panel_2(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_panel_3(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_panel_4(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_panel_5(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_purlin(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_rafter(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_rough_volume_framed_wall(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_rough_volume_log_home(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_rough_volume_solid_wood_wall(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_stud(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_tread(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_truss(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_user_1(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_user_2(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_user_3(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_user_4(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """
    def set_user_5(self)->None:
        """setter method - usage see https://docs.cadwork.com/projects/cwapi3dpython/en/latest/examples/cadwork/#output-type
        """

class element_type():
    def __init__(self) -> None:
        pass
    def isAdditionalElement(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isAuxiliary(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isCadwork(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isCircularAxis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isCircularBeam(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isConnectorAxis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isConnectorNode(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isContainer(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isDimension(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isDrillingAxis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isEaveAxis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isExportSolid(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isExportSolidScene(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isFloor(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isGlobalCut(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isGraphicalObject(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isLine(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isNestingParent(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isNone(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isNormalNode(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isOpening(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isPanel(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isRectangularAxis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isRectangularBeam(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isRoof(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isRoom(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isRotationElement(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isSectionTrace(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isSteelShape(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isSurface(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isTextDocument(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isWall(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def isWireAxis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_additional_element(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_auxiliary(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_cadwork(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_circular_axis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_circular_beam(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_connector_axis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_connector_node(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_container(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_dimension(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_drilling_axis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_eave_axis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_export_solid(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_export_solid_scene(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_floor(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_global_cut(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_graphical_object(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_line(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_nesting_parent(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_none(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_normal_node(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_opening(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_panel(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_rectangular_axis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_rectangular_beam(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_roof(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_room(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_rotation_element(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_section_trace(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_steel_shape(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_surface(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_text_document(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_wall(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """
    def is_wire_axis(self, element_type)->bool:
        """
        Args:
            element_type (element type): element type 

        Returns:
            bool: condition
        """

class rgb_color():
    def __init__(self) -> None:
        pass

class visibility_state():
    def __init__(self) -> None:
        pass
    
class activation_state():
    def __init__(self) -> None:
        pass

class point_3d():
    def __init__(self, x:float, y:float, z:float)->None:
        self.x = x
        self.y = y
        self.z = z
    def cross(self, another_point_3d):
        """cross product takes two vectors and produces a third vector that is orthogonal to both

        Args:
            point_3d (point_3d): a second vector

        Returns:
            point_3d: a third vector orthogonal to both
        """

    def distance(self, another_point_3d) -> float:
        """distance between to points

        Args:
            point_3d (point_3d): a second point

        Returns:
            float: distance
        """

    def dot(self, another_point_3d) -> float:
        """When calculating the dot product of two unit vectors, the result is always between -1 and +1.
        The scalar product of two vectors of given length is thus zero if they are perpendicular to each other, and maximum if they have the same direction.
        A negative dot product between two vectors means that the two vectors go in the opposite general direction.

        Args:
            point_3d (point_3d): a second vector

        Returns:
            float: value betweend 0.0 and 1.0
        """
        
    def magnitude(self) -> float:
        """magnitude of a vector is the length of the vector.

        Returns:
            float: vector length
        """

    def normalized(self):
        """A normalized vector is a vector with a length equal to one unit.

        Returns:
            point_3d: normalized vector
        """
    def invert(self):
        """Invert point_3d
        
        Returns:
            point_3d: inverted point_3d
        """

def get_auto_attribute_elements() -> List[int]:
    """Get ontly the elements of the selected types in the attribute manager dialog. All other elements will 
    get an empty attribute value.

    Returns:
        List[int]: element IDs
    """

def set_auto_attribute(elements: List[int], value:str) -> None:
    """Set the auto attribute to the selected element types. 

    Args:
        elements (List[int]): element IDs 
        value (str): attribute 
    """

class element_module_properties():
    def __init__(self) -> None:
        pass
    def get_cutting_element_priority(self)->int:
        """ToDo Documentation
        """
    def get_distribute_in_axis_direction_distance(self)->int:
        """ToDo Documentation
        """
    def get_distribute_in_axis_direction_number(self)->int:
        """ToDo Documentation
        """
    def get_distribute_perpendicular_to_axis_direction_distance(self)->int:
        """ToDo Documentation
        """
    def get_distribute_perpendicular_to_axis_direction_number(self)->int:
        """ToDo Documentation
        """
    def get_keep_in_center_Of_layer_current_wall(self)->str:
        """ToDo Documentation
        """
    def get_keep_in_center_Of_layer_neighbour_wall(self):
        """ToDo Documentation
        """
    def get_unique_layername(self):
        """ToDo Documentation
        """
    def is_auxiliary(self):
        """ToDo Documentation
        """
    def is_bottom_plate(self):
        """ToDo Documentation
        """
    def is_cutting_element(self):
        """ToDo Documentation
        """
    def is_distribute_in_axis_direction(self):
        """ToDo Documentation
        """
    def is_distribute_in_axis_direction_use_max_distance(self):
        """ToDo Documentation
        """
    def is_distribute_in_axis_direction_use_number(self):
        """ToDo Documentation
        """
    def is_distribute_perpendicular_to_axis_direction(self):
        """ToDo Documentation
        """
    def is_distribute_perpendicular_to_axis_direction_use_max_distance(self):
        """ToDo Documentation
        """
    def is_distribute_perpendicular_to_axis_direction_use_number(self):
        """ToDo Documentation
        """
    def is_element_from_detail(self):
        """ToDo Documentation
        """
    def is_keep_in_center_Of_layer_current_wall(self):
        """ToDo Documentation
        """
    def is_keep_in_center_Of_layer_neighbour_wall(self):
        """ToDo Documentation
        """
    def is_main_element(self):
        """ToDo Documentation
        """
    def is_move_according_length_axis(self):
        """ToDo Documentation
        """
    def is_move_according_thickness_axis(self):
        """ToDo Documentation
        """
    def is_move_with_top_of_wall(self):
        """ToDo Documentation
        """
    def is_no_collision_control(self):
        """ToDo Documentation
        """
    def is_no_inside_cover_control(self):
        """ToDo Documentation
        """
    def is_not_cut_with_cutting_element(self):
        """ToDo Documentation
        """
    def is_not_placed_at_end_of_wall(self):
        """ToDo Documentation
        """
    def is_not_placed_at_start_of_wall(self):
        """ToDo Documentation
        """
    def is_opening_lintel(self, active:bool):
        """ToDo Documentation
        """
    def is_opening_sill(self, active:bool):
        """ToDo Documentation
        """
    def is_solder_in_axis_direction(self):
        """ToDo Documentation
        """
    def is_stop_in_axis_direction(self):
        """ToDo Documentation
        """
    def is_stop_perpendicular_to_axis_direction(self):
        """ToDo Documentation
        """
    def is_strecht_according_length_axis(self):
        """ToDo Documentation
        """
    def is_strecht_according_thickness_axis(self):
        """ToDo Documentation
        """
    def is_stretch_with_opening_lintel(self):
        """ToDo Documentation
        """
    def is_stretch_with_opening_sill(self):
        """ToDo Documentation
        """
    def is_stretch_with_top_of_wall(self):
        """ToDo Documentation
        """
    def is_top_plate(self):
        """ToDo Documentation
        """
    def is_unique_layername(self):
        """ToDo Documentation
        """
    def is_use_for_detail_coordinate_system(self):
        """ToDo Documentation
        """
    def set_auxiliary(self, active:bool):
        """ToDo Documentation
        """
    def set_bottom_plate(self, active:bool):
        """ToDo Documentation
        """
    def set_cutting_element(self, active:bool, priority:int):
        """ToDo Documentation
        """
    def set_distribute_in_axis_direction_use_max_distance(self):
        """ToDo Documentation
        """
    def set_distribute_in_axis_direction_use_number(self):
        """ToDo Documentation
        """
    def set_distribute_in_axis_direction(self, active:bool, distance:int):
        """ToDo Documentation
        """
    def set_distribute_perpendicular_to_axis_direction_use_max_distance(self):
        """ToDo Documentation
        """
    def set_distribute_perpendicular_to_axis_direction_use_number(self):
        """ToDo Documentation
        """
    def set_distribute_perpendicular_to_axis_direction(self, active:bool, distance:int):
        """ToDo Documentation
        """
    def set_element_from_detail(self):
        """ToDo Documentation
        """
    def set_keep_in_center_Of_layer_current_wall(self):
        """ToDo Documentation
        """
    def set_keep_in_center_Of_layer_neighbour_wall(self):
        """ToDo Documentation
        """
    def set_keep_in_center_Of_rough_volume(self):
        """ToDo Documentation
        """
    def set_main_element(self):
        """ToDo Documentation
        """
    def set_move_according_length_axis(self):
        """ToDo Documentation
        """
    def set_move_according_thickness_axis(self):
        """ToDo Documentation
        """
    def set_move_with_top_of_wall(self, aActive:bool):
        """ToDo Documentation
        """
    def set_no_collision_control(self, active:bool):
        """ToDo Documentation
        """
    def set_no_inside_cover_control(self, active:bool):
        """ToDo Documentation
        """
    def set_not_cut_with_cutting_element(self, active:bool):
        """ToDo Documentation
        """
    def set_not_placed_at_end_of_wall(self, active:bool):
        """ToDo Documentation
        """
    def set_not_placed_at_start_of_wall(self, active:bool):
        """ToDo Documentation
        """
    def set_opening_lintel(self):
        """ToDo Documentation
        """
    def set_opening_sill(self):
        """ToDo Documentation
        """
    def set_solder_in_axis_direction(self, active:bool):
        """ToDo Documentation
        """
    def set_stop_in_axis_direction(self, active:bool):
        """ToDo Documentation
        """
    def set_stop_perpendicular_to_axis_direction(self, active:bool):
        """ToDo Documentation
        """
    def set_strecht_according_length_axis(self):
        """ToDo Documentation
        """
    def set_strecht_according_thickness_axis(self):
        """ToDo Documentation
        """
    def set_stretch_with_opening_lintel(self, active:bool):
        """ToDo Documentation
        """
    def set_stretch_with_opening_sill(self, active:bool):
        """ToDo Documentation
        """
    def set_stretch_with_top_of_wall(self, aActive:bool):
        """ToDo Documentation
        """
    def set_top_plate(self, active:bool):
        """ToDo Documentation
        """
    def set_unique_layername(self):
        """ToDo Documentation
        """
    def set_use_for_detail_coordinate_system(self, active:bool):
        """ToDo Documentation
        """

class ifc_2x3_element_type():
    def __init__(self) -> None:
        pass
    def is_ifc_beam(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_building_element_part(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_building_element_proxy(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_chimney(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_column(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_covering(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_curtain_wall(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_discrete_accessory(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_door(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_fastener(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_flow_segment(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_footing(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_furnishing_element(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_mechanical_fastener(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_member(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_opening_element(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_plate(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_railing(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_ramp(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_ramp_flight(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_roof(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_slab(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_space(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_stair(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_stair_flight(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_wall(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_wall_standard_case(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_ifc_window(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def is_none(self, ifc_type)->bool:
        """ToDo Documentation
        """
    def set_ifc_beam(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_building_element_part(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_building_element_proxy(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_chimney(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_column(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_covering(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_curtain_wall(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_discrete_accessory(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_door(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_fastener(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_flow_segment(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_footing(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_furnishing_element(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_mechanical_fastener(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_member(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_opening_element(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_plate(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_railing(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_ramp(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_ramp_flight(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_roof(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_slab(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_space(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_stair(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_stair_flight(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_wall(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_wall_standard_case(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_ifc_window(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """
    def set_none(self, element_ids:List[int], ifc_type)->None:
        """ToDo Documentation
        """


from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / 'README.md').read_text(encoding='utf-8')

setup(
    name='cwapi3d',
    version='1.3.1',
    author='Cadwork',
    author_email='it@cadwork.ca',
    description='Python bindings for CwAPI3D',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/cwapi3d/cwapi3dpython',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Plugins',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.9',
        'Topic :: Software Development :: Libraries',
    ],
    python_requires='>=3.9, <4',
    packages=[
        'attribute_controller',
        'bim_controller',
        'cadwork',
        'connector_axis_controller',
        'element_controller',
        'endtype_controller',
        'file_controller',
        'geometry_controller',
        'list_controller',
        'machine_controller',
        'material_controller',
        'menu_controller',
        'roof_controller',
        'scene_controller',
        'shop_drawing_controller',
        'utility_controller',
        'visualization_controller'
    ],
    package_dir={'': 'src'},
    package_data={
        '': ['*.pyi'],
    },
    include_package_data=True,
)



from typing import List

class point_3d:
    def __init__(self)->None:
        pass


def get_width(element: int) -> float: 
    """Get element width. 

    Args:
        element (int): element ID

    Returns:
        float: width
    """
def get_height(element: int) -> float: 
    """Get element height. 

    Args:
        element (int): element ID

    Returns:
        float: height
    """
def get_length(element: int) -> float: 
    """Get element length. 

    Args:
        element (int): element ID

    Returns:
        float: length
    """
def get_p1(element: int) -> point_3d: 
    """Get start Point of element. 

    Args:
        element (int): element ID

    Returns:
        point_3d: start point
    """
def get_p2(element: int) -> point_3d: 
    """Get end Point of element. 

    Args:
        element (int): element ID

    Returns:
        point_3d: end point
    """
def get_p3(element: int) -> point_3d: 
    """Point for orientation of the Z axis of the element. This point is on the same plane as point 1.

    Args:
        element (int): element ID

    Returns:
        point_3d: orientation point
    """
def get_start_height_cut_angle(element: int) -> float: 
    """get start height cut angle

    Args:
        element (int): element ID 

    Returns:
        float:  value
    """
def get_start_width_cut_angle(element: int) -> float: 
    """get start width cut angle

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_end_height_cut_angle(element: int) -> float: 
    """get end height cut angle

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_end_width_cut_angle(element: int) -> float: 
    """get end width cut angle

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def rotate_height_axis_90(elements: List[int]) -> None: 
    """rotate element height axis 90° 

    Args:
        elements (List[int]):  element IDs
    """
def rotate_height_axis_180(elements: List[int]) -> None: 
    """rotate element height axis 180° 

    Args:
        elements (List[int]):  element IDs
    """
def get_over_width(element: int) -> float: 
    """get over widht

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_over_width(element: int, value: float) -> None: 
    """set over width

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_over_height(element: int) -> float: 
    """get over height

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_over_height(element: int, value: float) -> None: 
    """set over height

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_over_length(element: int) -> float: 
    """get over length

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_over_length(element: int, value: float) -> None: 
    """set over length

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_rounding_width(element: int) -> float: 
    """get rounding width

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_rounding_width(element: int, value: float) -> None: 
    """set rounding width

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_rounding_height(element: int) -> float: 
    """get rounding height

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_rounding_height(element: int, value: float) -> None: 
    """set rounding height

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_rounding_length(element: int) -> float: 
    """get rounding length

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_rounding_length(element: int, value: float) -> None: 
    """set rounding length

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_cross_correction_negative_width(element: int) -> float: 
    """get cross correction negative width

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_cross_correction_negative_width(element: int, value: float) -> None: 
    """set cross correction negative width

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_cross_correction_positive_width(element: int) -> float: 
    """get cross correction positive width

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_cross_correction_positive_width(element: int, value: float) -> None: 
    """set cross correction positive width

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_cross_correction_negative_height(element: int) -> float: 
    """set cross correction negative height

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_cross_correction_negative_height(element: int, value: float) -> None: 
    """set cross correction negative height

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_cross_correction_positive_height(element: int) -> float: 
    """get cross correction positive height

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_cross_correction_positive_height(element: int, value: float) -> None: 
    """set cross correction positive height

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_cross_correction_negative_length(element: int) -> float: 
    """get cross correction negative length

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_cross_correction_negative_length(element: int, value: float) -> None: 
    """set cross correction negative length

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_cross_correction_positive_length(element: int) -> float: 
    """get cross correction positive length

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_cross_correction_positive_length(element: int, value: float) -> None: 
    """set cross correction positive length

    Args:
        element (int): element ID
        value (float):  a value
    """
def get_weight(element: int) -> float: 
    """get element weight

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_list_weight(element: int) -> float: 
    """get element list weight 

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_volume(element: int) -> float: 
    """get element volume

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_list_volume(element: int) -> float: 
    """get element list volume

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_xl(element: int) -> point_3d: 
    """get local X vector

    Args:
        element (int): element ID

    Returns:
        point_3d: point_3d (x,y,z)
    """
def get_yl(element: int) -> point_3d: 
    """get local Y vector

    Args:
        element (int): element ID

    Returns:
        point_3d: point_3d (x,y,z)
    """
def get_zl(element: int) -> point_3d: 
    """get local Z vector

    Args:
        element (int): element ID

    Returns:
        point_3d: point_3d (x,y,z)
    """
def get_center_of_gravity(element: int) -> point_3d: 
    """get center of gravity geometrical 

    Args:
        element (int): element ID

    Returns:
        point_3d: point_3d (x,y,z)
    """
def get_center_of_gravity_for_list_considering_materials(elements: List[int]) -> point_3d: 
    """get center of gravity considering material weights 

    Args:
        elements (List[int]):  element IDs

    Returns:
        point_3d: point_3d (x,y,z)
    """
def get_reference_side(element: int) -> int: 
    """get element reference side. 

    Args:
        element (int): element ID

    Returns:
        int: face ID
    """
def get_element_vertices(element: int) -> List[point_3d]: 
    """get BREP vertices of element

    Args:
        element (int): element ID

    Returns:
        List[point_3d]: vertex list
    """
def apply_global_scale(elements: List[int], scale: float, origin: point_3d) -> None: 
    """apply global scale

    Args:
        elements (List[int]):  element IDs
        scale (float): scale factor
        origin (point_3d): a origin
    """
def auto_regenerate_axes(elements: List[int]) -> None: 
    """regenerate element axis system

    Args:
        elements (List[int]):  element IDs
    """
def rotate_length_axis_90(elements: List[int]) -> None: 
    """rotate length axis 90°

    Args:
        elements (List[int]):  element IDs
    """
def rotate_length_axis_180(elements: List[int]) -> None: 
    """rotate length axis 180°

    Args:
        elements (List[int]):  element IDs
    """
def invert_model(elements: List[int]) -> None: 
    """Inverts element model

    Args:
        elements (List[int]):  element IDs
    """
def get_element_facets(element: int) -> List[List[point_3d]]: 
    """get element facets in a nested list

    Args:
        element (int): element ID

    Returns:
        List[List[point_3d]]: nested vertex list
    """
def get_list_width(element: int) -> float: 
    """get list width

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_list_height(element: int) -> float: 
    """get list height

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_list_length(element: int) -> float: 
    """get list length

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def set_width_real(elements: List[int], value: float) -> None: 
    """set width real

    Args:
        elements (List[int]):  element IDs
        value (float):  a value
    """
def set_height_real(elements: List[int], value: float) -> None: 
    """set height real

    Args:
        elements (List[int]):  element IDs
        value (float):  a value
    """
def set_length_real(elements: List[int], value: float) -> None: 
    """set length real

    Args:
        elements (List[int]):  element IDs
        value (float):  a value
    """
def rotate_height_axis_2_points(elements: List[int], start: point_3d, end: point_3d) -> None: 
    """rotate height axis via 2 points. The axis is defined by a point 1 and a point 2. 

    Args:
        elements (List[int]):  element IDs
        start (point_3d): start point
        end (point_3d): end point
    """
def get_minimum_distance_between_elements(first_element: int, second_element: int) -> float: 
    """get the minimum distance between two elements

    Args:
        first_element (int): element ID
        second_element (int): element ID

    Returns:
        float:  value
    """
def get_total_area_of_all_faces(element: int) -> float: 
    """get total area fo all element faces

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_area_of_front_face(element: int) -> float: 
    """get area of reference face

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_door_surface(elements: List[int]) -> float: 
    """get door surface

    Args:
        elements (List[int]):  element IDs

    Returns:
        float:  value
    """
def get_window_surface(elements: List[int]) -> float: 
    """get window surface

    Args:
        elements (List[int]):  element IDs

    Returns:
        float:  value
    """
def get_local_x() -> point_3d: 
    """X vector of the coordinate system in 3D

    Args:
        element (int): element ID

    Returns:
        point_3d: point_3d (x,y,z)
    """
def get_local_z() -> point_3d: 
    """Z vector of the coordinate system in 3D

    Args:
        element (int): element ID

    Returns:
        point_3d: point_3d (x,y,z)
    """
def get_local_y(element: int) -> point_3d: 
    """Y vector of the coordinate system in 3D

    Args:
        element (int): element ID

    Returns:
        point_3d: point_3d (x,y,z)
    """
def set_drilling_tolerance(elements: List[int], value: float) -> None: 
    """set drilling tolerance

    Args:
        elements (List[int]):  element IDs
        value (float):  a value
    """
def get_drilling_tolerance(element: int) -> float: 
    """get drilling tolerance

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def get_element_reference_face_vertices(element: int) -> List[point_3d]: 
    """get element reference face vertices.

    Args:
        element (int): element ID

    Returns:
        List[point_3d]: vertex list
    """
def get_element_reference_face_area(element: int) -> float: 
    """get element reference face area

    Args:
        element (int): element ID

    Returns:
        float:  value
    """
def auto_regenerate_axes_silently(elements: List[int]) -> None: 
    """automatic, silent regeneration of element axes 

    Args:
        elements (List[int]):  element IDs
    """
def rotate_length_axis_2_points(elements: List[int], start: point_3d, end: point_3d) -> None: 
    """rotate length axis via 2 points. The axis is defined by a point 1 and a point 2. 

    Args:
        elements (List[int]):  element IDs
        start (point_3d): start point
        end (point_3d): end point
    """
def get_center_of_gravity_for_list(elements: List[int]) -> point_3d: 
    """get geometrical center of gravity for elements. 

    Args:
        elements (List[int]):  element IDs

    Returns:
        point_3d: point_3d (x,y,z)
    """
